<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Snapshot location:</source>
        <translation>Umístnění snímku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot je program pro tvorbu bootovacích obrazů (ISO) z Vašeho funkčího systému, které můžete použít jako zálohu nebo pro distribuci. Počas tvorby zálohy můžete pracovat s méně náročnými aplikacemi.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Zabrané místo na discích / (root) a /home:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Snapshot name:</source>
        <translation>Název snímku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Select a different snapshot directory</source>
        <translation>Vyberte jinou složku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>lz4</source>
        <translation>lz4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>lzo</source>
        <translation>lzo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <source>gzip</source>
        <translation>gzip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>xz</source>
        <translation>xz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="276"/>
        <source>TextLabel</source>
        <translation>Textový popis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Downloads</source>
        <translation>Stažené soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>All of the above</source>
        <translation>Všechno co je výš</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Desktop</source>
        <translation>Pracovní plocha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Videos</source>
        <translation>Videa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Tato volba zresetuje &amp;quot;demo&amp;quot; a &amp;quot;root&amp;quot; hesla na výrobní nastavení MX Linux a nepřenese žádné účty uživatelů.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Resetovat uživatelské účty (pro distribuci jiným)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Type of snapshot:</source>
        <translation>Typ snímku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Zachovat uživatelské účty (pro osobní zálohu)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>ISO compression scheme:</source>
        <translation>Schéma komprese ISO:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Edit Exclusion File</source>
        <translation>Editovat soubor výjimek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Calculate checksums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>Next</source>
        <translation>Následující</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Used space on / (root): </source>
        <translation type="vanished">Zabrané místo na disku / (root):</translation>
    </message>
    <message>
        <source>Used space on /home: </source>
        <translation type="vanished">Zabrané místo na disku /home: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Volné místo na %1, kde je snapshot umístněn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="148"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>Velikost volného místa na disku by měla postačovat pro umístnění zkomprimovaného obsahu z / a /home

      Ak je to nevyhnutné můžete vytvořit víc místa smazáním
      předchozích snapshotů a uložeých kopií systému:
      %1 snapshoty zabírají %2 místa na disku.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Installing </source>
        <translation>Instalace</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Could not install </source>
        <translation type="vanished">Nelze nainstalovat</translation>
    </message>
    <message>
        <source>Building new initrd...</source>
        <translation type="vanished">Vytváření nového initrd...</translation>
    </message>
    <message>
        <source>Copying the new-iso filesystem...</source>
        <translation type="vanished">Kopírování nového ISO souborového systému...</translation>
    </message>
    <message>
        <source>Squashing filesystem...</source>
        <translation type="vanished">Rušení souborového systému...</translation>
    </message>
    <message>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">Nelze vytvořit soubor linuxfs, prosím zkontrolujte zdali je dostatek místa na vybraném oddílu.</translation>
    </message>
    <message>
        <source>Creating CD/DVD image file...</source>
        <translation type="vanished">Vytváření obrazu CD/DVD... </translation>
    </message>
    <message>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">Nelze vytvořit ISO soubor, prosím zkontrolujte zdali je dostatek místa na vybraném oddílu.</translation>
    </message>
    <message>
        <source>Making hybrid iso</source>
        <translation type="vanished">Vytváření hybridního ISO</translation>
    </message>
    <message>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="vanished">MX Snapshot úspěšně ukončen!</translation>
    </message>
    <message>
        <source>Snapshot took %1 to finish.</source>
        <translation type="vanished">Snímek dokončen za %1.</translation>
    </message>
    <message>
        <source>Making md5sum</source>
        <translation type="vanished">Vytváření md5sum</translation>
    </message>
    <message>
        <source>Cleaning...</source>
        <translation type="vanished">Čištění...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">Hotovo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>Please wait.</source>
        <translation>Prosím vyčkejte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Prosím vyčkejte. Propočítávání použitého místa na disku...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>Snapshot použije následující nastavení:*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>- Snapshot directory:</source>
        <translation>- Složka Snapshotu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>- Kernel to be used:</source>
        <translation>- Verze jádra:</translation>
    </message>
    <message>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="vanished">Současné jádro nepodporuje vybraný algoritmus komprese, prosím upravte konfigurační soubor a vyberte jiný algoritmus.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Final chance</source>
        <translation>Poslední šance</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Snapshot sesbíral všechny potřebné informace k vytvoření ISO z běžícího systému.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Nějakou chvilku to zabere, závisí to od velikosti instalovaného systému a výkonu Vašeho počítače.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>OK to start?</source>
        <translation>Začít?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Could not create temporary directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Edit Boot Menu</source>
        <translation>Upravit nabídku zavaděče</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>Program se teď pozastaví a umožní Vám upravit soubory v pracovní složce. Zvolte ANO pro editaci nabídky zavaděče, volbou NE přeskočíte tento krok a přejděte k tvorbě snapshotu. </translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="vanished">Úspěch!</translation>
    </message>
    <message>
        <source>All finished!</source>
        <translation type="vanished">Dokončeno!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Program pro tvorbu LIVE CD z běžícího systému MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Select Snapshot Directory</source>
        <translation>Vyberte složku pro snímek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Confirmation</source>
        <translation>Potvrzení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Jste si jistí, že chcete ukončit aplikaci? </translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <location filename="../about.cpp" line="44"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Chyba</translation>
    </message>
    <message>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="vanished">Současné jádro nepodporuje Squashfs, nelze pokračovat.</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Tuto aplikaci musíte spustit jako root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Use CLI only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Output filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Or the full path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation type="unfinished">Resetovat uživatelské účty (pro distribuci jiným)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Exclude main folders, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Desktop, Documents, Downloads, Music, Networks, Pictures, Videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>one item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Compression format, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>You must run this program as root.</source>
        <translation type="unfinished">Tuto aplikaci musíte spustit jako root.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="122"/>
        <location filename="../main.cpp" line="177"/>
        <source>Error</source>
        <translation type="unfinished">Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="123"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>version, or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="178"/>
        <location filename="../settings.cpp" line="209"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished">Současné jádro nepodporuje Squashfs, nelze pokračovat.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <location filename="../main.cpp" line="129"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="56"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="87"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="105"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="202"/>
        <source>Could not find a usable kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="283"/>
        <source>Used space on / (root): </source>
        <translation type="unfinished">Zabrané místo na disku / (root):</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="286"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="295"/>
        <source>Used space on /home: </source>
        <translation type="unfinished">Zabrané místo na disku /home: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="347"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation type="unfinished">Volné místo na %1, kde je snapshot umístněn:</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="349"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished">Velikost volného místa na disku by měla postačovat pro umístnění zkomprimovaného obsahu z / a /home

      Ak je to nevyhnutné můžete vytvořit víc místa smazáním
      předchozích snapshotů a uložeých kopií systému:
      %1 snapshoty zabírají %2 místa na disku.
</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="364"/>
        <source>Desktop</source>
        <translation type="unfinished">Pracovní plocha</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="365"/>
        <source>Documents</source>
        <translation type="unfinished">Dokumenty</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="366"/>
        <source>Downloads</source>
        <translation type="unfinished">Stažené soubory</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="367"/>
        <source>Music</source>
        <translation type="unfinished">Hudba</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="368"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="369"/>
        <source>Pictures</source>
        <translation type="unfinished">Obrázky</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="370"/>
        <source>Videos</source>
        <translation type="unfinished">Videa</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="115"/>
        <source>Interrupted or failed to complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="35"/>
        <location filename="../work.cpp" line="55"/>
        <location filename="../work.cpp" line="62"/>
        <location filename="../work.cpp" line="68"/>
        <location filename="../work.cpp" line="208"/>
        <location filename="../work.cpp" line="225"/>
        <location filename="../work.cpp" line="262"/>
        <location filename="../work.cpp" line="307"/>
        <location filename="../work.cpp" line="338"/>
        <source>Error</source>
        <translation type="unfinished">Chyba</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="35"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished">Současné jádro nepodporuje vybraný algoritmus komprese, prosím upravte konfigurační soubor a vyberte jiný algoritmus.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="56"/>
        <location filename="../work.cpp" line="63"/>
        <location filename="../work.cpp" line="69"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="57"/>
        <location filename="../work.cpp" line="64"/>
        <location filename="../work.cpp" line="70"/>
        <source>You have %1 free space on %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="95"/>
        <source>Cleaning...</source>
        <translation type="unfinished">Čištění...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="111"/>
        <location filename="../work.cpp" line="114"/>
        <location filename="../work.cpp" line="247"/>
        <source>Done</source>
        <translation type="unfinished">Hotovo</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="149"/>
        <source>Copying the new-iso filesystem...</source>
        <translation type="unfinished">Kopírování nového ISO souborového systému...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="177"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="206"/>
        <source>Squashing filesystem...</source>
        <translation type="unfinished">Rušení souborového systému...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="208"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">Nelze vytvořit soubor linuxfs, prosím zkontrolujte zdali je dostatek místa na vybraném oddílu.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="223"/>
        <source>Creating CD/DVD image file...</source>
        <translation type="unfinished">Vytváření obrazu CD/DVD... </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="225"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">Nelze vytvořit ISO soubor, prosím zkontrolujte zdali je dostatek místa na vybraném oddílu.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="232"/>
        <source>Making hybrid iso</source>
        <translation type="unfinished">Vytváření hybridního ISO</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="248"/>
        <source>Success</source>
        <translation type="unfinished">Úspěch!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="248"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished">MX Snapshot úspěšně ukončen!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="249"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished">Snímek dokončen za %1.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="250"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="259"/>
        <source>Installing </source>
        <translation type="unfinished">Instalace</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="262"/>
        <source>Could not install </source>
        <translation type="unfinished">Nelze nainstalovat</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="272"/>
        <source>Calculating checksum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="307"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="316"/>
        <source>Building new initrd...</source>
        <translation type="unfinished">Vytváření nového initrd...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="338"/>
        <source>Could not find %1 file, cannot continue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
